@@ -5,7 +5,7 @@
 #  File author(s): Thomas Cokelaer <cokelaer@gmail.com>
 #
 """Common tools to get the correct filename and pathname. """
-__version__ = "$Rev: 41 $"
+__version__ = "$Rev: 47 $"
 import pkg_resources
 try:
     version = pkg_resources.require("easydev")[0].version
@@ -15,6 +15,9 @@ except:
 import copybutton
 from copybutton import *
 
+import decorators
+from decorators import *
+
 import doc
 from doc import *
 
